package handler

import (
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"fusenapi/server/product-template/internal/logic"
	"fusenapi/server/product-template/internal/svc"
	"fusenapi/server/product-template/internal/types"
)

func AddBaseMapHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {

		var (
			// 定义错误变量
			err error
			// 定义用户信息变量
			userinfo *auth.BackendUserInfo
		)
		// 解析JWT token,并对空用户进行判断
		claims, err := svcCtx.ParseJwtToken(r)
		// 如果解析JWT token出错,则返回未授权的JSON响应并记录错误消息
		if err != nil || claims == nil {
			httpx.OkJsonCtx(r.Context(), w, &basic.Response{
				Code:    401,            // 返回401状态码,表示未授权
				Message: "unauthorized", // 返回未授权信息
			})
			logx.Info("unauthorized:", err.Error()) // 记录错误日志
			return
		}

		// 从token中获取对应的用户信息
		userinfo, err = auth.GetBackendUserInfoFormMapClaims(claims)
		// 如果获取用户信息出错,则返回未授权的JSON响应并记录错误消息
		if err != nil {
			httpx.OkJsonCtx(r.Context(), w, &basic.Response{
				Code:    401,
				Message: "unauthorized",
			})
			logx.Info("unauthorized:", err.Error())
			return
		}

		var req types.AddBaseMapReq

		// 创建一个业务逻辑层实例
		l := logic.NewAddBaseMapLogic(r.Context(), svcCtx)
		resp := l.AddBaseMap(&req, userinfo)

	}
}
